@@ -1,3 +1,5 @@
+from typing import Callable, List
+
 import altair as alt
 import numpy as np
 import pandas as pd
@@ -6,7 +8,9 @@ from profiling.metrics import getloss
 from profiling.utils import df_to_json_table
 
 
-def metrics(func, X, y, kind, formatstr="{:,.2f}"):
+def metrics(
+    func: Callable[[pd.DataFrame], pd.Series], x: pd.DataFrame, y: pd.Series, kind: str
+) -> str:
     if kind == "regression":
         loss_list = ["Rmse", "Mae", "TrimmedRmse", "MeanPrediction", "MeanActual"]
     elif kind == "binary":
@@ -14,8 +18,8 @@ def metrics(func, X, y, kind, formatstr="{:,.2f}"):
     else:
         raise NotImplementedError(f"Unknown endpoint kind: {kind}")
 
-    pred = func(X)
-    losses = [getloss(x) for x in loss_list]
+    pred = func(x)
+    losses = [getloss(ll) for ll in loss_list]
     loss_names = [loss.name for loss in losses]
     loss_values = [loss.metric(pred, y) for loss in losses]
     table = pd.DataFrame({"Metric": loss_names, "Value": loss_values})
@@ -23,15 +27,21 @@ def metrics(func, X, y, kind, formatstr="{:,.2f}"):
     return df_to_json_table(table, date_format="iso", date_unit="s", double_precision=2)
 
 
-def largest_errors(func, X, y, profile_columns, n=25):
+def largest_errors(
+    func: Callable[[pd.DataFrame], pd.Series],
+    x: pd.DataFrame,
+    y: pd.Series,
+    profile_columns: List[str],
+    n: int = 25,
+) -> str:
     """Return observations with largest errors in predictions"""
-    pred = func(X).to_numpy()
+    pred = func(x).to_numpy()
 
     df = (
-        X[profile_columns]
+        x[profile_columns]
         .assign(y=y, pred=pred)  # to numpy is needed to help time inference
         .astype({"y": float, "pred": float})  # account for boolean output/predictions
-        .assign(Delta=lambda x: np.abs(x["y"] - x["pred"]))
+        .assign(Delta=lambda k: np.abs(k["y"] - k["pred"]))
     )
 
     df = df.sort_values("Delta", ascending=False).head(n)
@@ -40,15 +50,20 @@ def largest_errors(func, X, y, profile_columns, n=25):
     # Move new columns to the beginning
     cols = df.columns.to_list()
     first = ["Predicted Value", "Actual Value", "Delta"]
-    last = [x for x in cols if x not in first]
+    last = [c for c in cols if c not in first]
     df = df.reindex(columns=first + last)
 
     return df_to_json_table(df, date_format="iso", date_unit="s", double_precision=2)
 
 
-def calibration(func, X, y, bins=10):
+def calibration(
+    func: Callable[[pd.DataFrame], pd.Series],
+    x: pd.DataFrame,
+    y: pd.Series,
+    bins: int = 10,
+) -> alt.Chart:
     """Plot calibration"""
-    preds = func(X).to_numpy()
+    preds = func(x).to_numpy()
     pred_grp = pd.qcut(preds, q=bins, duplicates="drop")
 
     df = pd.DataFrame(
