@@ -24,7 +24,11 @@ def mkdir(endpoint_name, spec_path=""):
 
 
 def create_shapley_schema(
-    func: Callable, x: pandas.DataFrame, endpoint_name: str, profile_columns: List[str],
+    func: Callable,
+    x: pandas.DataFrame,
+    endpoint_name: str,
+    profile_columns: List[str],
+    explain_input_example: List[Dict],
 ):
     """Create shapley schema for endpoint"""
 
@@ -36,7 +40,12 @@ def create_shapley_schema(
     fname = "schema.json"
     fpath = os.path.join(folder, fname)
     example = x.head(1)
-    data = create_explainer_schema(example, explainer, input_descriptions,)
+    data = create_explainer_schema(
+        explainer_schema_example=example,
+        explainer=explainer,
+        input_descriptions=input_descriptions,
+        explain_input_example=explain_input_example,
+    )
     with open(fpath, "w") as f:
         json.dump(jsonable_encoder(data), f)
 
@@ -45,6 +54,7 @@ def create_explainer_schema(
     explainer_schema_example: pandas.DataFrame,
     explainer: ShapExplainer,
     input_descriptions: List[Dict],
+    explain_input_example: List[Dict],
 ) -> Dict:
     """Create schema for explainer input"""
 
@@ -52,7 +62,7 @@ def create_explainer_schema(
     baseline, explanation = explainer.explain(explainer_schema_example)
 
     example = {
-        "inputs": df_to_dict(explainer_schema_example),  # schema_example,
+        "inputs": explain_input_example,
         "explanations": df_to_dict(explanation),
         "prediction": list(pred),
         "baseline": list(baseline),
